@@ -438,7 +438,7 @@ srtp_err_status_t cipher_array_alloc_init(srtp_cipher_t ***ca,
 {
     int i, j;
     srtp_err_status_t status;
-    uint8_t *key;
+    uint8_t *key = NULL;
     srtp_cipher_t **cipher_array;
     /* pad klen allocation, to handle aes_icm reading 16 bytes for the
        14-byte salt */
@@ -453,11 +453,13 @@ srtp_err_status_t cipher_array_alloc_init(srtp_cipher_t ***ca,
     /* set ca to location of cipher_array */
     *ca = cipher_array;
 
-    /* allocate key */
-    key = srtp_crypto_alloc(klen_pad);
-    if (key == NULL) {
-        srtp_crypto_free(cipher_array);
-        return srtp_err_status_alloc_fail;
+    /* allocate key , allow zero key for example null cipher */
+    if (klen_pad > 0) {
+        key = srtp_crypto_alloc(klen_pad);
+        if (key == NULL) {
+            srtp_crypto_free(cipher_array);
+            return srtp_err_status_alloc_fail;
+        }
     }
 
     /* allocate and initialize an array of ciphers */
