@@ -96,45 +96,46 @@ static struct srtp_crypto_suite srtp_crypto_suites[] = {
 #if 0
   {.can_name = "F8_128_HMAC_SHA1_32", .gcm_on = 0, .key_size = 128, .tag_size = 4},
 #endif
-    {.can_name = "AES_CM_128_HMAC_SHA1_32",
-     .gcm_on = 0,
-     .key_size = 128,
-     .tag_size = 4 },
-    {.can_name = "AES_CM_128_HMAC_SHA1_80",
-     .gcm_on = 0,
-     .key_size = 128,
-     .tag_size = 10 },
-    {.can_name = "AES_192_CM_HMAC_SHA1_32",
-     .gcm_on = 0,
-     .key_size = 192,
-     .tag_size = 4 },
-    {.can_name = "AES_192_CM_HMAC_SHA1_80",
-     .gcm_on = 0,
-     .key_size = 192,
-     .tag_size = 10 },
-    {.can_name = "AES_256_CM_HMAC_SHA1_32",
-     .gcm_on = 0,
-     .key_size = 256,
-     .tag_size = 4 },
-    {.can_name = "AES_256_CM_HMAC_SHA1_80",
-     .gcm_on = 0,
-     .key_size = 256,
-     .tag_size = 10 },
-    {.can_name = "AEAD_AES_128_GCM",
-     .gcm_on = 1,
-     .key_size = 128,
-     .tag_size = 16 },
-    {.can_name = "AEAD_AES_256_GCM",
-     .gcm_on = 1,
-     .key_size = 256,
-     .tag_size = 16 },
-    {.can_name = NULL }
+    { .can_name = "AES_CM_128_HMAC_SHA1_32",
+      .gcm_on = 0,
+      .key_size = 128,
+      .tag_size = 4 },
+    { .can_name = "AES_CM_128_HMAC_SHA1_80",
+      .gcm_on = 0,
+      .key_size = 128,
+      .tag_size = 10 },
+    { .can_name = "AES_192_CM_HMAC_SHA1_32",
+      .gcm_on = 0,
+      .key_size = 192,
+      .tag_size = 4 },
+    { .can_name = "AES_192_CM_HMAC_SHA1_80",
+      .gcm_on = 0,
+      .key_size = 192,
+      .tag_size = 10 },
+    { .can_name = "AES_256_CM_HMAC_SHA1_32",
+      .gcm_on = 0,
+      .key_size = 256,
+      .tag_size = 4 },
+    { .can_name = "AES_256_CM_HMAC_SHA1_80",
+      .gcm_on = 0,
+      .key_size = 256,
+      .tag_size = 10 },
+    { .can_name = "AEAD_AES_128_GCM",
+      .gcm_on = 1,
+      .key_size = 128,
+      .tag_size = 16 },
+    { .can_name = "AEAD_AES_256_GCM",
+      .gcm_on = 1,
+      .key_size = 256,
+      .tag_size = 16 },
+    { .can_name = NULL }
 };
 
 void rtp_decoder_srtp_log_handler(srtp_log_level_t level,
                                   const char *msg,
                                   void *data)
 {
+    (void)data;
     char level_char = '?';
     switch (level) {
     case srtp_log_level_error:
@@ -173,10 +174,12 @@ int main(int argc, char *argv[])
     struct bpf_program fp;
     char filter_exp[MAX_FILTER] = "";
     char pcap_file[MAX_FILE] = "-";
-    int rtp_packet_offset = DEFAULT_RTP_OFFSET;
+    size_t rtp_packet_offset = DEFAULT_RTP_OFFSET;
     rtp_decoder_t dec;
-    srtp_policy_t policy = { { 0 } };
+    srtp_policy_t policy = { 0 };
     rtp_decoder_mode_t mode = mode_rtp;
+    srtp_ssrc_t ssrc = { ssrc_any_inbound, 0 };
+    uint32_t roc = 0;
     srtp_err_status_t status;
     int len;
     int expected_len;
@@ -202,7 +205,7 @@ int main(int argc, char *argv[])
 
     /* check args */
     while (1) {
-        c = getopt_s(argc, argv, "b:k:gt:ae:ld:f:s:m:p:o:");
+        c = getopt_s(argc, argv, "b:k:gt:ae:ld:f:c:m:p:o:s:r:");
         if (c == -1) {
             break;
         }
@@ -256,7 +259,7 @@ int main(int argc, char *argv[])
         case 'l':
             do_list_mods = 1;
             break;
-        case 's':
+        case 'c':
             for (i_scsp = &srtp_crypto_suites[0]; i_scsp->can_name != NULL;
                  i_scsp++) {
                 if (strcasecmp(i_scsp->can_name, optarg_s) == 0) {
@@ -297,6 +300,13 @@ int main(int argc, char *argv[])
         case 'o':
             rtp_packet_offset = atoi(optarg_s);
             break;
+        case 's':
+            ssrc.type = ssrc_specific;
+            ssrc.value = strtol(optarg_s, NULL, 0);
+            break;
+        case 'r':
+            roc = atoi(optarg_s);
+            break;
         default:
             usage(argv[0]);
         }
@@ -540,14 +550,16 @@ int main(int argc, char *argv[])
         }
         /* check that hex string is the right length */
         if (len < expected_len) {
-            fprintf(stderr, "error: too few digits in key/salt "
-                            "(should be %d digits, found %d)\n",
+            fprintf(stderr,
+                    "error: too few digits in key/salt "
+                    "(should be %d digits, found %d)\n",
                     expected_len, len);
             exit(1);
         }
-        if (strlen(input_key) > policy.rtp.cipher_key_len * 2) {
-            fprintf(stderr, "error: too many digits in key/salt "
-                            "(should be %d hexadecimal digits, found %u)\n",
+        if (strlen(input_key) > (size_t)policy.rtp.cipher_key_len * 2) {
+            fprintf(stderr,
+                    "error: too many digits in key/salt "
+                    "(should be %d hexadecimal digits, found %u)\n",
                     policy.rtp.cipher_key_len * 2, (unsigned)strlen(input_key));
             exit(1);
         }
@@ -565,6 +577,13 @@ int main(int argc, char *argv[])
         exit(1);
     }
 
+    policy.ssrc = ssrc;
+
+    if (roc != 0 && policy.ssrc.type != ssrc_specific) {
+        fprintf(stderr, "error: setting ROC (-r) requires -s <ssrc>\n");
+        exit(1);
+    }
+
     pcap_handle = pcap_open_offline(pcap_file, errbuf);
 
     if (!pcap_handle) {
@@ -588,7 +607,7 @@ int main(int argc, char *argv[])
         exit(1);
     }
     fprintf(stderr, "Starting decoder\n");
-    if (rtp_decoder_init(dec, policy, mode, rtp_packet_offset)) {
+    if (rtp_decoder_init(dec, policy, mode, rtp_packet_offset, roc)) {
         fprintf(stderr, "error: init failed\n");
         exit(1);
     }
@@ -620,8 +639,8 @@ void usage(char *string)
 {
     fprintf(
         stderr,
-        "usage: %s [-d <debug>]* [[-k][-b] <key>] [-a][-t][-e] [-s "
-        "<srtp-crypto-suite>] [-m <mode>]\n"
+        "usage: %s [-d <debug>]* [[-k][-b] <key>] [-a][-t][-e] [-c "
+        "<srtp-crypto-suite>] [-m <mode>] [-s <ssrc> [-r <roc>]]\n"
         "or     %s -l\n"
         "where  -a use message authentication\n"
         "       -e <key size> use encryption (use 128 or 256 for key size)\n"
@@ -632,11 +651,15 @@ void usage(char *string)
         "       -l list debug modules\n"
         "       -f \"<pcap filter>\" to filter only the desired SRTP packets\n"
         "       -d <debug> turn on debugging for module <debug>\n"
-        "       -s \"<srtp-crypto-suite>\" to set both key and tag size based\n"
+        "       -c \"<srtp-crypto-suite>\" to set both key and tag size based\n"
         "          on RFC4568-style crypto suite specification\n"
         "       -m <mode> set the mode to be one of [rtp]|rtcp|rtcp-mux\n"
         "       -p <pcap file> path to pcap file (defaults to stdin)\n"
-        "       -o byte offset of RTP packet in capture (defaults to 42)\n",
+        "       -o byte offset of RTP packet in capture (defaults to 42)\n"
+        "       -s <ssrc> restrict decrypting to the given SSRC (in host byte "
+        "order)\n"
+        "       -r <roc> initial rollover counter, requires -s <ssrc> "
+        "(defaults to 0)\n",
         string, string);
     exit(1);
 }
@@ -662,7 +685,8 @@ int rtp_decoder_deinit(rtp_decoder_t decoder)
 int rtp_decoder_init(rtp_decoder_t dcdr,
                      srtp_policy_t policy,
                      rtp_decoder_mode_t mode,
-                     int rtp_packet_offset)
+                     size_t rtp_packet_offset,
+                     uint32_t roc)
 {
     dcdr->rtp_offset = rtp_packet_offset;
     dcdr->srtp_ctx = NULL;
@@ -674,11 +698,16 @@ int rtp_decoder_init(rtp_decoder_t dcdr,
     dcdr->rtcp_cnt = 0;
     dcdr->mode = mode;
     dcdr->policy = policy;
-    dcdr->policy.ssrc.type = ssrc_any_inbound;
 
     if (srtp_create(&dcdr->srtp_ctx, &dcdr->policy)) {
         return 1;
     }
+
+    if (policy.ssrc.type == ssrc_specific && roc != 0) {
+        if (srtp_set_stream_roc(dcdr->srtp_ctx, policy.ssrc.value, roc)) {
+            return 1;
+        }
+    }
     return 0;
 }
 
@@ -688,11 +717,11 @@ int rtp_decoder_init(rtp_decoder_t dcdr,
 
 void hexdump(const void *ptr, size_t size)
 {
-    int i, j;
+    size_t i, j;
     const unsigned char *cptr = ptr;
 
     for (i = 0; i < size; i += 16) {
-        fprintf(stdout, "%04x ", i);
+        fprintf(stdout, "%04x ", (unsigned int)i);
         for (j = 0; j < 16 && i + j < size; j++) {
             fprintf(stdout, "%02x ", cptr[i + j]);
         }
@@ -764,7 +793,7 @@ void rtp_decoder_handle_pkt(u_char *arg,
         dcdr->rtcp_cnt++;
     }
     timersub(&hdr->ts, &dcdr->start_tv, &delta);
-    fprintf(stdout, "%02ld:%02ld.%06ld\n", delta.tv_sec / 60, delta.tv_sec % 60,
-            (long)delta.tv_usec);
+    fprintf(stdout, "%02ld:%02d.%06ld\n", (long)(delta.tv_sec / 60),
+            (int)(delta.tv_sec % 60), (long)delta.tv_usec);
     hexdump(&message, octets_recvd);
 }
